intersectionRatioThreshold property
Required overlap ratio between the face and target frame.
Implementation
final double intersectionRatioThreshold;
Required overlap ratio between the face and target frame.
final double intersectionRatioThreshold;