FaceDetectionConfig class

Constructors

FaceDetectionConfig({String message = '', TextStyle messageStyle = const TextStyle(color: Colors.white), bool showControls = true, bool showCaptureControl = true, bool showFlashControl = true, bool showCameraLensControl = true, bool showStatusMessage = true, IndicatorShape indicatorShape = IndicatorShape.defaultShape, bool autoDisableCaptureControl = false, bool autoCapture = false, ImageResolution imageResolution = ImageResolution.high, CameraFlashMode defaultFlashMode = CameraFlashMode.off, CameraOrientation orientation = CameraOrientation.portraitUp, FaceDetectorMode performanceMode = FaceDetectorMode.fast, AccuracyConfig? accuracyConfig})
FaceDetectionConfig.fromMap(Map<String, dynamic>? map)
factory

Properties

accuracyConfig AccuracyConfig?
final
autoCapture bool
final
autoDisableCaptureControl bool
final
defaultFlashMode → CameraFlashMode
final
hashCode int
The hash code for this object.
no setterinherited
imageResolution → ImageResolution
final
indicatorShape → IndicatorShape
final
message String
final
messageStyle TextStyle
final
orientation → CameraOrientation
final
performanceMode → FaceDetectorMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCameraLensControl bool
final
showCaptureControl bool
final
showControls bool
final
showFlashControl bool
final
showStatusMessage bool
final

Methods

copyWith({String? message, TextStyle? messageStyle, bool? showControls, bool? showCaptureControl, bool? showFlashControl, bool? showCameraLensControl, bool? showStatusMessage, IndicatorShape? indicatorShape, bool? autoDisableCaptureControl, bool? autoCapture, ImageResolution? imageResolution, CameraFlashMode? defaultFlashMode, CameraOrientation? orientation, FaceDetectorMode? performanceMode, AccuracyConfig? accuracyConfig}) FaceDetectionConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited