FaceDetectionController class

Inheritance

Constructors

FaceDetectionController()

Properties

faceCameraController ↔ FaceCameraController?
getter/setter pair
faceDetectionConfig FaceDetectionConfig
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
initialCamera ↔ CameraLens
getter/setter pair
lastSetterProperty ↔ KeyValue?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispatchChanges(KeyValue changedProperty) → void
inherited
dispose() → void
Discards any resources used by the object.
override
getBaseGetters() Map<String, Function>
inherited
getBaseMethods() Map<String, Function>
inherited
getBaseSetters() Map<String, Function>
inherited
init(BuildContext context, dynamic onCapture(File?)?, dynamic onError(dynamic)?) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setInitialCamera(String? cameraLens) → void
toString() String
A string representation of this object.
inherited
updateConfig(Map<String, dynamic> partialConfig) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited