FaceDetectionResult class

Constructors

FaceDetectionResult({bool detected = false, double? left, double? top, double? width, double? height, String? message})

Properties

detected bool
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
left double?
final
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double?
final
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited