FaceDetectionResult class

Annotations
  • @JS.new()
  • @anonymous

Constructors

FaceDetectionResult({bool detected, double? left, double? top, double? width, double? height, String? message})
factory

Properties

detected bool
no setter
hashCode int
The hash code for this object.
no setterinherited
height double?
no setter
left double?
no setter
message String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double?
no setter
width double?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited