SmartFaceCameraWeb class

Inheritance

Constructors

SmartFaceCameraWeb({Key? key, String message = '', TextStyle messageStyle = const TextStyle(color: Colors.white), bool showControls = true, bool showCaptureControl = true, bool showFlashControl = true, bool showCameraLensControl = true, bool showStatusMessage = true, IndicatorShape indicatorShape = IndicatorShape.defaultShape, bool autoDisableCaptureControl = false, bool autoCapture = false, dynamic onCapture(File)?, dynamic onError(dynamic)?})
const

Properties

autoCapture bool
final
autoDisableCaptureControl bool
final
hashCode int
The hash code for this object.
no setterinherited
indicatorShape → IndicatorShape
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message String
final
messageStyle TextStyle
final
onCapture → dynamic Function(File)?
final
onError → dynamic Function(dynamic)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCameraLensControl bool
final
showCaptureControl bool
final
showControls bool
final
showFlashControl bool
final
showStatusMessage bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SmartFaceCameraWeb>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited