WebFaceDetection class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
faceDetected
→ ValueNotifier<
bool> -
final
-
faceHeight
→ ValueNotifier<
double?> -
final
-
faceLeft
→ ValueNotifier<
double?> -
final
-
faceTop
→ ValueNotifier<
double?> -
final
-
faceWidth
→ ValueNotifier<
double?> -
final
-
statusMessage
→ ValueNotifier<
String> -
final
Static Methods
-
dispose(
) → void -
getAspectRatio(
) → double? -
getCameraController(
) → CameraController? -
getCameras(
) → List< CameraDescription> -
getFlashMode(
) → FlashMode -
initializeCamera(
{required CameraLens initialLens, required dynamic onError(dynamic), ImageResolution imageResolution = ImageResolution.high, CameraFlashMode defaultFlashMode = CameraFlashMode.off, IndicatorShape indicatorShape = IndicatorShape.defaultShape, AccuracyConfig? accuracyConfig}) → Future< void> -
isFlashSupported(
) → bool -
markAutoCaptured(
) → void -
setFlashMode(
FlashMode mode) → Future< bool> -
setPerformanceMode(
FaceDetectorMode mode) → void -
shouldAutoCapture(
bool autoCapture) → bool -
switchCamera(
) → Future< void> -
takePicture(
) → Future< String?>