WebFaceDetection class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
faceDetected
↔ ValueNotifier<
bool> -
getter/setter pair
-
faceHeight
↔ ValueNotifier<
double?> -
getter/setter pair
-
faceLeft
↔ ValueNotifier<
double?> -
getter/setter pair
-
faceTop
↔ ValueNotifier<
double?> -
getter/setter pair
-
faceWidth
↔ ValueNotifier<
double?> -
getter/setter pair
-
statusMessage
↔ ValueNotifier<
String> -
getter/setter pair
Static Methods
-
captureImage(
) → Future< String?> -
detectFace(
{bool accurateMode = false, Map< String, dynamic> ? accuracyConfig}) → Future<FaceDetectionResult> -
dispose(
) → void - Clean up resources
-
getAspectRatio(
) → double? - Get camera aspect ratio
-
getCameraController(
) → CameraController? - Get camera controller
-
getCameras(
) → List< CameraDescription> - Get cameras list
-
getFlashMode(
) → FlashMode? - Get camera flash mode
-
getImageResolution(
) → ImageResolution - Get current image resolution
-
getIndicatorShape(
) → IndicatorShape - Get current indicator shape
-
initialize(
) → Future< void> -
initializeCamera(
{required CameraLens initialLens, required dynamic onError(dynamic), ImageResolution imageResolution = ImageResolution.high, CameraFlashMode defaultFlashMode = CameraFlashMode.off, IndicatorShape indicatorShape = IndicatorShape.defaultShape, AccuracyConfig? accuracyConfig}) → Future< void> - Initialize camera and start face detection
-
isFlashSupported(
) → bool - Check if flash is supported
-
markAutoCaptured(
) → void - Mark that auto capture has been done
-
setDefaultFlashMode(
CameraFlashMode mode) → void - Set default flash mode for camera
-
setFlashMode(
FlashMode mode) → Future< bool> - Set camera flash mode
-
setImageResolution(
ImageResolution resolution) → void - Set image resolution for camera
-
setIndicatorShape(
IndicatorShape shape) → void - Set indicator shape for face detection
-
setPerformanceMode(
FaceDetectorMode mode) → void - Set performance mode for face detection
-
shouldAutoCapture(
bool autoCapture) → bool - Check if camera should auto-capture based on face detection and settings
-
startFaceDetection(
) → void - Start periodic face detection
-
switchCamera(
) → Future< void> - Switch between front and back cameras
-
takePicture(
) → Future< File?> - Capture image from camera